guix-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[shepherd] 08/09: Replace "dmd" with "shepherd" in comments and strings.


From: Alex Kost
Subject: [shepherd] 08/09: Replace "dmd" with "shepherd" in comments and strings.
Date: Tue, 26 Jan 2016 09:40:28 +0000

alezost pushed a commit to branch master
in repository shepherd.

commit 67db25d1d1b92b4b8b3a5fdb30aed30f9b23bd57
Author: Alex Kost <address@hidden>
Date:   Mon Jan 25 13:06:07 2016 +0300

    Replace "dmd" with "shepherd" in comments and strings.
    
    * modules/shepherd/support.scm: Use "shepherd" instead of "dmd"
      everywhere.
    * configure.ac: Likewise.
    * tests/no-home.sh: Likewise.
    * tests/sigint.sh: Likewise.
---
 configure.ac                 |    2 +-
 modules/shepherd/support.scm |   16 ++++++++--------
 tests/no-home.sh             |    2 +-
 tests/sigint.sh              |    2 +-
 4 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/configure.ac b/configure.ac
index f89604c..478994c 100644
--- a/configure.ac
+++ b/configure.ac
@@ -34,7 +34,7 @@ else
 fi
 AC_MSG_RESULT($recent_version)
 if test $recent_version = no; then
-  AC_MSG_WARN(your Guile is probably too old to run dmd)
+  AC_MSG_WARN(your Guile is probably too old to run shepherd)
 fi
 
 AC_PATH_PROG([GUILD], [guild])
diff --git a/tests/no-home.sh b/tests/no-home.sh
index 32fa842..85b6116 100644
--- a/tests/no-home.sh
+++ b/tests/no-home.sh
@@ -35,7 +35,7 @@ herd="herd -s $socket"
 trap "rm -f $socket;
       test -f $pid && kill \`cat $pid\` || true; rm -f $pid" EXIT
 
-# Make sure 'dmd' starts even though $HOME is not writable.
+# Make sure 'shepherd' starts even though $HOME is not writable.
 shepherd -I -s "$socket" -c /dev/null -l /dev/null --pid="$pid" &
 shepherd_pid="$!"
 
diff --git a/tests/sigint.sh b/tests/sigint.sh
index 4c78ff7..253bf04 100644
--- a/tests/sigint.sh
+++ b/tests/sigint.sh
@@ -48,7 +48,7 @@ shepherd -I -s "$socket" -c "$conf" --pid="$pid" &
 
 while [ ! -f "$pid" ] ; do sleep 0.5 ; done
 
-# Send SIGINT to dmd.
+# Send SIGINT to shepherd.
 kill -INT "`cat "$pid"`"
 while kill -0 "`cat "$pid"`" ; do sleep 0.5 ; done
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/modules/shepherd/support.scm b/modules/shepherd/support.scm
index 68a8c80..83456bb 100644
--- a/modules/shepherd/support.scm
+++ b/modules/shepherd/support.scm
@@ -1,4 +1,4 @@
 ;; support.scm -- Various support facilities, used by herd and dmd.
 ;; Copyright (C) 2014 A.Sassmannshausen <address@hidden>
 ;; Copyright (C) 2013, 2014, 2016 Ludovic Courtès <address@hidden>
 ;; Copyright (C) 2002, 2003 Wolfgang Jährling <address@hidden>
@@ -231,7 +231,7 @@ There is NO WARRANTY, to the extent permitted by law.")))
 ;; Home directory of the user.
 (define user-homedir
   ;; Look for $HOME first, to allow users to override the defaults.  This is
   ;; notably useful when dmd is built in a Guix chroot.
   (or (getenv "HOME")
 
       ;; When bootstrapping and running as PID 1, /etc/{passwd,shadow} may be
@@ -252,17 +252,17 @@ TARGET should be a string representing a filepath + name."
   (with-output-to-file target
     (lambda ()
       (display (string-append
-                ";; init.scm -- default dmd configuration file.
+                ";; init.scm -- default shepherd configuration file.
 
 ;; Services known to dmd:
 ;; Add new services (defined using 'make <service>') to dmd here by
 ;; providing them as arguments to 'register-services'.
 ""(register-services)
 
 ;; Send shepherd into the background
 ""(action 'shepherd 'daemonize)
 
 ;; Services to start when dmd starts:
 ;; Add the name of each service that should be started to the list
 ;; below passed to 'for-each'.
 ""(for-each start '())
@@ -297,7 +297,7 @@ create a template configuration file if non exists."
       %system-socket-dir
       (string-append %user-config-dir "/run")))
 
 ;; Unix domain socket for receiving commands in dmd.
 (define default-socket-file
   (string-append default-socket-dir "/socket"))
 
@@ -311,7 +311,7 @@ create a template configuration file if non exists."
       (string-append %localstatedir "/lib/shepherd/state")
       (string-append %user-config-dir "/state")))
 
 ;; Global variables set from (dmd).
 (define persistency #f)
 (define persistency-state-file default-persistency-state-file)
 
@@ -1,4 +1,4 @@
-;; support.scm -- Various support facilities, used by herd and dmd.
+;; support.scm -- Various support facilities, used by herd and shepherd.
 ;; Copyright (C) 2014 A.Sassmannshausen <address@hidden>
 ;; Copyright (C) 2013, 2014, 2016 Ludovic Courtès <address@hidden>
@@ -231,7 +231,7 @@ There is NO WARRANTY, to the extent permitted by law.")))
 (define user-homedir
   ;; Look for $HOME first, to allow users to override the defaults.  This is
-  ;; notably useful when dmd is built in a Guix chroot.
+  ;; notably useful when shepherd is built in a Guix chroot.
   (or (getenv "HOME")
 
@@ -252,17 +252,17 @@ TARGET should be a string representing a filepath + name."
 
-;; Services known to dmd:
-;; Add new services (defined using 'make <service>') to dmd here by
+;; Services known to shepherd:
+;; Add new services (defined using 'make <service>') to shepherd here by
 ;; providing them as arguments to 'register-services'.
 ""(register-services)
@@ -252,17 +252,17 @@ TARGET should be a string representing a filepath + name."
 ""(action 'shepherd 'daemonize)
 
-;; Services to start when dmd starts:
+;; Services to start when shepherd starts:
 ;; Add the name of each service that should be started to the list
 ;; below passed to 'for-each'.
@@ -297,7 +297,7 @@ create a template configuration file if non exists."
       (string-append %user-config-dir "/run")))
 
-;; Unix domain socket for receiving commands in dmd.
+;; Unix domain socket for receiving commands in shepherd.
 (define default-socket-file
   (string-append default-socket-dir "/socket"))
@@ -311,7 +311,7 @@ create a template configuration file if non exists."
       (string-append %user-config-dir "/state")))
 
-;; Global variables set from (dmd).
+;; Global variables set from (shepherd).
 (define persistency #f)
 (define persistency-state-file default-persistency-state-file)